summaryrefslogtreecommitdiffstats
path: root/arch/arm/mach-netx
diff options
context:
space:
mode:
authorSascha Hauer <s.hauer@pengutronix.de>2009-12-15 09:11:09 +0100
committerSascha Hauer <s.hauer@pengutronix.de>2009-12-15 10:18:30 +0100
commita3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97 (patch)
tree7a9076c1a20df00baeadca9a07d4c1f5cd0611e2 /arch/arm/mach-netx
parentcaa5cec7b1c93d660aa89d24eb160ab18e4eb628 (diff)
downloadbarebox-a3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97.tar.gz
barebox-a3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97.tar.xz
rename U-Boot-v2 project to barebox
This has been done with the following script: find -path ./.git -prune -o -type f -print0 | xargs -0 -r sed -i \ -e 's/u2boot/barebox/g' \ -e 's/U2Boot/barebox/g' \ -e 's/U-boot V2/barebox/g' \ -e 's/u-boot v2/barebox/g' \ -e 's/U-Boot V2/barebox/g' \ -e 's/U-Boot-v2/barebox/g' \ -e 's/U_BOOT/BAREBOX/g' \ -e 's/UBOOT/BAREBOX/g' \ -e 's/uboot/barebox/g' \ -e 's/u-boot/barebox/g' \ -e 's/u_boot/barebox/g' \ -e 's/U-Boot/barebox/g' \ -e 's/U-boot/barebox/g' \ -e 's/U-BOOT/barebox/g' find -path ./.git -prune -o \( -name "*u-boot*" -o -name "*uboot*" -o -name "*u_boot*" \) -print0 | \ xargs -0 -r rename 's/u[-_]?boot/barebox/' It needs some manual fixup following in the next patch Signed-off-by: Sascha Hauer <s.hauer@pengutronix.de>
Diffstat (limited to 'arch/arm/mach-netx')
-rw-r--r--arch/arm/mach-netx/generic.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/arch/arm/mach-netx/generic.c b/arch/arm/mach-netx/generic.c
index 4af945f4d6..76ae6bdfec 100644
--- a/arch/arm/mach-netx/generic.c
+++ b/arch/arm/mach-netx/generic.c
@@ -91,7 +91,7 @@ int loadxc(int xcno) {
memset32((void*)NETX_PA_XPEC(xcno) + XPEC_RAM_START, 0, 0x2000);
memset32((void*)NETX_PA_XMAC(xcno), 0, 0x800);
/* can't use u-boot memcpy here, we need 32bit accesses */
if(xcno == 0) {
memcpy32((void*)(NETX_PA_XMAC(xcno) + XMAC_RPU_PROGRAM_START), rpu_eth0, sizeof(rpu_eth0));
memcpy32((void*)(NETX_PA_XMAC(xcno) + XMAC_TPU_PROGRAM_START), tpu_eth0, sizeof(tpu_eth0));
@@ -143,8 +143,8 @@ void reset_cpu(ulong addr)
}
-U_BOOT_CMD_START(loadxc)
+BAREBOX_CMD_START(loadxc)
.cmd = do_loadxc,
.usage = "load xmac/xpec engine with ethernet firmware",
-U_BOOT_CMD_END
+BAREBOX_CMD_END
@@ -91,7 +91,7 @@ int loadxc(int xcno) {
memset32((void*)NETX_PA_XPEC(xcno) + XPEC_RAM_START, 0, 0x2000);
memset32((void*)NETX_PA_XMAC(xcno), 0, 0x800);
- /* can't use u-boot memcpy here, we need 32bit accesses */
+ /* can't use barebox memcpy here, we need 32bit accesses */
if(xcno == 0) {
memcpy32((void*)(NETX_PA_XMAC(xcno) + XMAC_RPU_PROGRAM_START), rpu_eth0, sizeof(rpu_eth0));